==> quassel_0.4.1.orig.tar.gz: quassel-0.4.1/src/client/clientbufferviewconfig.h <==
/***************************************************************************
 *   Copyright (C) 2005-08 by the Quassel Project                          *
 *   devel@quassel-irc.org                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) version 3.                                           *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef CLIENTBUFFERVIEWCONFIG_H
#define CLIENTBUFFERVIEWCONFIG_H

#include "bufferviewconfig.h"

class ClientBufferViewConfig : public BufferViewConfig {
  Q_OBJECT

public:
  ClientBufferViewConfig(int bufferViewId, QObject *parent = 0);

  inline bool isLocked() { return _locked || sortAlphabetically(); }
  inline void setLocked(bool locked) { _locked = locked; }
  inline void lock() { setLocked(true); };
  inline void unlock() { setLocked(false); };

private slots:
  void ensureDecoration(); // remove this in next release

private:
  bool _locked;
};

#endif //CLIENTBUFFERVIEWCONFIG_H

==> quassel_0.13.1.orig.tar.gz: quassel-0.13.1/src/client/clientbufferviewconfig.h <==
/***************************************************************************
 *   Copyright (C) 2005-2019 by the Quassel Project                        *
 *   devel@quassel-irc.org                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) version 3.                                           *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef CLIENTBUFFERVIEWCONFIG_H
#define CLIENTBUFFERVIEWCONFIG_H

#include "bufferviewconfig.h"

class ClientBufferViewConfig : public BufferViewConfig
{
    SYNCABLE_OBJECT
        Q_OBJECT

public:
    ClientBufferViewConfig(int bufferViewId, QObject *parent = 0);

    inline bool isLocked() { return _locked || sortAlphabetically(); }
    inline void setLocked(bool locked) { _locked = locked; }
    inline void lock() { setLocked(true); };
    inline void unlock() { setLocked(false); };

private slots:
    void ensureDecoration(); // remove this in next release

private:
    bool _locked;
};


#endif //CLIENTBUFFERVIEWCONFIG_H
